.. _utils.landmarks:

Landmark Extraction
===================

.. automodule:: eyetrace.utils.landmarks
   :members:
   :undoc-members:
   :show-inheritance:

This submodule provides functions to extract specific facial landmarks
from MediaPipe Face Mesh, including eye landmarks (6 points per eye),
iris landmarks (5 points per iris), and a general landmark array.